=======
Contact
=======

If you've scoured the :ref:`conceptual <concepts-docs>` and :ref:`API
<api-docs>` documentation and still can't find an answer to your question,
below are various support resources that should help. We do request that you do
at least skim the documentation before posting tickets or mailing list
questions, however!

Mailing list
------------

The best way to get help with using Fabric is via the `fab-user mailing list
<http://lists.nongnu.org/mailman/listinfo/fab-user>`_ (currently hosted at
``nongnu.org``.) The Fabric developers do their best to reply promptly, and the
list contains an active community of other Fabric users and contributors as
well.

Twitter
-------

Fabric has an official Twitter account, `@pyfabric
<https://twitter.com/pyfabric>`_, which is used for announcements and occasional
related news tidbits (e.g. "Hey, check out this neat article on Fabric!").

You may also want to follow the principal developer, `@bitprophet
<https://twitter.com/bitprophet>`_, for development updates and colorful
commentary.

.. _bugs:

Bugs/ticket tracker
-------------------

To file new bugs or search existing ones, you may visit Fabric's `Github Issues
<https://github.com/fabric/fabric/issues>`_ page. This does require a (free, easy to set up) Github account.

.. _irc:

Blog posts
----------

The developer posts occasional (but usually important) news on his blog; there
is a dedicated Fabric category: https://bitprophet.org/categories/fabric/
